﻿########################################################################################################
# Scriptname: ImportCert.ps1
# Author: Michael Rüefli
# Purpose: Import PKCS12 certificates from a file share into local certificate store (Machine or User)
# Version: 1.0
# 
# Fixed Issues / Changes:
# V 1.0.1 / Changed the autogenerated password strenght
########################################################################################################

function ConvertToSid([STRING]$NtAccount) 
{
	$result = (New-Object system.security.principal.NtAccount($NTaccount)).translate([system.security.principal.securityidentifier])
	return $result.value
}

#Get the Arguments
$importpath = $args[0]
$certstore = $args[1]

#Check the Args
If ($args.count -lt 2)
{
	write-host "Too less arguments! Usage: ImportCert.ps1 <importpath> <certstore>" -ForegroundColor red
	write-host "Example: Powershell.exe ImportCert.ps1 H:\Certs CurrentUser" -ForegroundColor blue
	exit
}

#Error Handler
Trap [Exception]{continue}


function Import-PfxCertificate 
{     
   param([String]$certPath,[String]$certRootStore,[String]$certStore,$pfxPass = $null,[String]$KeySet)     

	#Error Handler
	Trap [Exception]{continue}

	if ($args[0] -eq "-h") 
   {
		Write-Host "usage: Import-509Certificate <Filename>,<certstore>,<cert root>,<keyset> `n `
		Valid certstores: LocalMachine,CurrentUser `n `
		Valid cert root: My,AuthRoot,TrustedPublisher `n `
        Valid Keysets: MachineKeySet,UserKeySet"
		break
   }
   
   write-host "Importing Certificate: $certPath"
   $pfx = new-object System.Security.Cryptography.X509Certificates.X509Certificate2     
   if ($pfxPass -eq $null) {$pfxPass = read-host "Enter the pfx password" -assecurestring}     
   $pfx.import($certPath,$pfxPass,"MachineKeySet,Exportable,PersistKeySet")     
   $store = new-object System.Security.Cryptography.X509Certificates.X509Store($certStore,$certRootStore)     
   $store.open("MaxAllowed")     
   $store.add($pfx)     
   $store.close()     
}    


$username = $env:USERNAME
$certs = Get-ChildItem $importpath -Filter "*.pfx"
Foreach ($item in $certs)
{
	$item
	$friendlypath = $item.FullName
	$friendlyname = ($item.Name).replace(".pfx","")
	$sid = ConvertToSid $username
	"$friendlyname-$username"
	$pass = "$friendlyname-$sid"
	$pass_secure = ConvertTo-SecureString -AsPlainText $pass -Force
	Import-PfxCertificate "$friendlypath" "$certstore" "My" $pass_secure
}



